# radiation tagger

exif_rad.py is a simple unix-style cross-platform Python 3 tool which can write certain tags to an image file.

It can scan a couple of images, extract their Exif-tags, and compare the `DateTimeOriginal` with other sources.

By now it can parse a .his (CSV) file from a [GeigerLog](https://sourceforge.net/projects/geigerlog/) file export and calculate the radiation in µS/h using the factor in `SIFACTOR`.

It then creates a `UserComment` Exif tag with the actual measured radiation at the time the photo has been taken.

## Dependencies
Right now it depends on the following Python 3 libraries:

  * [piexif](https://pypi.org/project/pyexif/): Python module for working with EXIF image data.

## Requirements
  * GeigerCounter log file in csv format as it is being exported by the software GeigerLog. Such files look like this: `149654, 2020-02-27 05:12:42,    13.0,     0.0`
  * A bunch of images (jpg, cr2, etc.) with its time of creation stored in `DateTimeOriginal`
  * A gpx track

All sources are matched by their timestamp, so all sources have to be recorded during the same time (and timezone)

## Usage

```usage: exif_rad.py [-h] [-si SIFACTOR] [-o OUTDIR] CSV Photo [Photo ...]

A tool that writes radiation levels (and optionally geocoordinates) to image
files and extracts the infos from external sources.

positional arguments:
  CSV                   Geiger counter history file in CSV format.
  Photo                 One or multiple photo image files to process.

optional arguments:
  -h, --help            show this help message and exit
  -si SIFACTOR, --sifactor SIFACTOR
                        Factor to multiply recorded CPM with. (default:
                        0.0065)
  -o OUTDIR, --outdir OUTDIR
                        Directory to output processed photos (default: .)
```


## future possibilities

  * In the future it should also be able to do the same with a gpx-file to extract geolocations and to write them into the appropiate Exif-fields.
  * It might get a setup.py if I want to waste my time on it.
  * I might want to get rid of the requirement to use a bloated GUI application to download the history data off the geigercounter. There must be a neat working command line tool. Maybe I'll write it myswlf.
